package org.dromara.ems.base.service;

import org.dromara.ems.base.domain.EmsAlarmActionStepImage;

import java.util.List;

/**
 * 报警措施步骤图片Service接口
 * 
 * @author zch
 * @date 2025-05-29
 */
public interface IEmsAlarmActionStepImageService 
{
    /**
     * 查询报警措施步骤图片
     * 
     * @param objId 报警措施步骤图片主键
     * @return 报警措施步骤图片
     */
    public EmsAlarmActionStepImage selectEmsAlarmActionStepImageByObjId(String objId);

    /**
     * 查询报警措施步骤图片列表
     * 
     * @param emsAlarmActionStepImage 报警措施步骤图片
     * @return 报警措施步骤图片集合
     */
    public List<EmsAlarmActionStepImage> selectEmsAlarmActionStepImageList(EmsAlarmActionStepImage emsAlarmActionStepImage);

    /**
     * 新增报警措施步骤图片
     * 
     * @param emsAlarmActionStepImage 报警措施步骤图片
     * @return 结果
     */
    public int insertEmsAlarmActionStepImage(EmsAlarmActionStepImage emsAlarmActionStepImage);

    /**
     * 修改报警措施步骤图片
     * 
     * @param emsAlarmActionStepImage 报警措施步骤图片
     * @return 结果
     */
    public int updateEmsAlarmActionStepImage(EmsAlarmActionStepImage emsAlarmActionStepImage);

    /**
     * 批量删除报警措施步骤图片
     * 
     * @param objIds 需要删除的报警措施步骤图片主键集合
     * @return 结果
     */
    public int deleteEmsAlarmActionStepImageByObjIds(String[] objIds);

    /**
     * 删除报警措施步骤图片信息
     * 
     * @param objId 报警措施步骤图片主键
     * @return 结果
     */
    public int deleteEmsAlarmActionStepImageByObjId(String objId);
}
